maildir_deduplicate package
===========================

Subpackages
-----------

.. toctree::

    maildir_deduplicate.tests

Submodules
----------

maildir_deduplicate.cli module
------------------------------

.. automodule:: maildir_deduplicate.cli
    :members:
    :undoc-members:
    :show-inheritance:

maildir_deduplicate.deduplicate module
--------------------------------------

.. automodule:: maildir_deduplicate.deduplicate
    :members:
    :undoc-members:
    :show-inheritance:

maildir_deduplicate.mail module
-------------------------------

.. automodule:: maildir_deduplicate.mail
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: maildir_deduplicate
    :members:
    :undoc-members:
    :show-inheritance:
